@@ -21,7 +21,7 @@
 
 """grabber.py tests"""
 
-# $Id: test_grabber.py,v 1.24 2005/02/25 00:00:36 mstenner Exp $
+# $Id: test_grabber.py,v 1.28 2005/10/22 21:57:27 mstenner Exp $
 
 import sys
 import os
@@ -92,6 +92,15 @@ class HTTPTests(TestCase):
 
         self.assertEqual(contents, reference_data)
 
+    def test_post(self):
+        "do an HTTP post"
+        headers = (('Content-type', 'text/plain'),)
+        ret = grabber.urlread(base_http + 'test_post.php',
+                              data=short_reference_data,
+                              http_headers=headers)
+
+        self.assertEqual(ret, short_reference_data)
+
 class URLGrabberModuleTestCase(TestCase):
     """Test module level functions defined in grabber.py"""
     def setUp(self):
@@ -227,7 +236,8 @@ class FailureTestCase(TestCase):
     def test_failure_callback_called(self):
         "failure callback is called on retry"
         self.failure_callback_called = 0
-        g = grabber.URLGrabber(retry=2,failure_callback=self._failure_callback)
+        g = grabber.URLGrabber(retry=2, retrycodes=[14],
+                               failure_callback=self._failure_callback)
         try: g.urlgrab(ref_404)
         except URLGrabError: pass
         self.assertEquals(self.failure_callback_called, 1)
@@ -235,7 +245,8 @@ class FailureTestCase(TestCase):
     def test_failure_callback_args(self):
         "failure callback is called with the proper args"
         fc = (self._failure_callback, ('foo',), {'bar': 'baz'})
-        g = grabber.URLGrabber(retry=2,failure_callback=fc)
+        g = grabber.URLGrabber(retry=2, retrycodes=[14],
+                               failure_callback=fc)
         try: g.urlgrab(ref_404)
         except URLGrabError: pass
         self.assert_(hasattr(self, 'obj'))
@@ -248,6 +259,42 @@ class FailureTestCase(TestCase):
         self.assert_(isinstance(self.obj.exception, URLGrabError))
         del self.obj
 
+class InterruptTestCase(TestCase):
+    """Test interrupt callback behavior"""
+
+    class InterruptProgress:
+        def start(self, *args, **kwargs): pass
+        def update(self, *args, **kwargs): raise KeyboardInterrupt
+        def end(self, *args, **kwargs): pass
+
+    class TestException(Exception): pass
+
+    def _interrupt_callback(self, obj, *args, **kwargs):
+        self.interrupt_callback_called = 1
+        self.obj = obj
+        self.args = args
+        self.kwargs = kwargs
+        if kwargs.get('exception', None):
+            raise kwargs['exception']
+        
+    def test_interrupt_callback_called(self):
+        "interrupt callback is called on retry"
+        self.interrupt_callback_called = 0
+        ic = (self._interrupt_callback, (), {})
+        g = grabber.URLGrabber(progress_obj=self.InterruptProgress(),
+                               interrupt_callback=ic)
+        try: g.urlgrab(ref_http)
+        except KeyboardInterrupt: pass
+        self.assertEquals(self.interrupt_callback_called, 1)
+
+    def test_interrupt_callback_raises(self):
+        "interrupt callback raises an exception"
+        ic = (self._interrupt_callback, (),
+              {'exception': self.TestException()})
+        g = grabber.URLGrabber(progress_obj=self.InterruptProgress(),
+                               interrupt_callback=ic)
+        self.assertRaises(self.TestException, g.urlgrab, ref_http)
+
 class CheckfuncTestCase(TestCase):
     """Test checkfunc behavior"""
 
@@ -452,6 +499,23 @@ class BaseProxyTests(TestCase):
             have_proxy = 0
         return have_proxy
 
+class ProxyFormatTests(BaseProxyTests):
+    def setUp(self):
+        grabber._proxy_cache = []
+
+    def tearDown(self):
+        grabber._proxy_cache = []
+
+    def test_good_proxy_formats(self):
+        for f in ['http://foo.com/', 'http://user:pass@foo.com:8888']:
+            h = grabber.CachedProxyHandler({'http': f})
+        
+    def test_bad_proxy_formats(self):
+        for f in ['foo.com', 'foo.com:8888', 'user:pass@foo.com:8888']:
+            self.assertRaises(URLGrabError, grabber.CachedProxyHandler,
+                              {'http': f})
+        
+
 class ProxyHTTPAuthTests(BaseProxyTests):
     def setUp(self):
         self.url = ref_http
